use strict;
use warnings;

package CORBA::XMLSchemas;

our $VERSION = '2.60';

1;

